@@ -1,28 +1,30 @@
 """Module containing the Data Store Collection class."""
 from __future__ import annotations
-from .__version__ import __title__, __documentation__, __version__  # noqa
 
+import json
 import re
 from functools import total_ordering
+from typing import TYPE_CHECKING
 from xml.etree import ElementTree
-import json
 
 import requests
 
-from typing import TYPE_CHECKING
+from .__version__ import __documentation__, __title__, __version__  # noqa
 
 if TYPE_CHECKING:  # pragma: no cover
     import sys
-    from typing import Optional, Any
+    from typing import Any, Optional
 
     if sys.version_info < (3, 9):
-        from typing import Mapping, MutableMapping, Generator, Pattern
+        from typing import Generator, Mapping, MutableMapping, Pattern
     else:
         from collections.abc import Mapping, MutableMapping, Generator
         from re import Pattern
     from eumdac.datastore import DataStore
     from eumdac.product import Product
 
+from eumdac.errors import EumdacError, eumdac_raise_for_status
+
 
 class SearchResults:
     collection: Collection
@@ -46,7 +48,7 @@ class SearchResults:
         params = self._get_request_params()
         with requests.Session() as session:
             page_json = self._load_page(params, session=session)
-            self._total_results = int(page_json["properties"]["totalResults"])
+            self._total_results = int(page_json["totalResults"])
             yield from self._yield_products(page_json)
             for start_index in range(
                 self._items_per_page, self._total_results, self._items_per_page
@@ -67,7 +69,7 @@ class SearchResults:
             params = self._get_request_params()
             params["c"] = 0
             page_json = self._load_page(params)
-            self._total_results = int(page_json["properties"]["totalResults"])
+            self._total_results = int(page_json["totalResults"])
         return self._total_results
 
     @property
@@ -80,7 +82,7 @@ class SearchResults:
         new_keys = set(query)
         diff = new_keys.difference(valid_keys)
         if diff:
-            raise ValueError(f"invalid search options {diff}")
+            raise CollectionError(f"invalid search options {diff}")
         self._query = {
             key: None if query.get(key) is None else str(query.get(key)) for key in valid_keys
         }
@@ -93,7 +95,7 @@ class SearchResults:
         params = self._get_request_params()
         params["c"] = 1
         page_json = self._load_page(params)
-        self._total_results = page_json["properties"]["totalResults"]
+        self._total_results = page_json["totalResults"]
         if self._total_results == 0:
             return None
         return next(self._yield_products(page_json))
@@ -119,7 +121,11 @@ class SearchResults:
             )
         else:
             response = session.get(url, params=params, auth=auth)
-        response.raise_for_status()
+        eumdac_raise_for_status(
+            f"Search query load page failed for {self.collection} with {self._query}",
+            response,
+            CollectionError,
+        )
         return response.json()
 
     def _yield_products(self, page_json: Mapping[str, Any]) -> Generator[Product, None, None]:
@@ -192,7 +198,9 @@ class Collection:
                 "User-Agent": str(__title__ + "/" + __version__),
             },
         )
-        response.raise_for_status()
+        eumdac_raise_for_status(
+            f"Could not get properties of {self._id}", response, CollectionError
+        )
         geometry = response.json()["collection"]["geometry"]
         properties = response.json()["collection"]["properties"]
         properties.pop("links")
@@ -229,7 +237,7 @@ class Collection:
         """Product type"""
         self._ensure_properties()
         auth = self.datastore.token._access_token
-        url = "https://api.eumetsat.int/epcs/0.1.0/products"
+        url = self.datastore.urls.get("tailor", "products")
         response = requests.get(
             url,
             headers={
@@ -271,7 +279,8 @@ class Collection:
             # load remote options
             # this lines may change when the new version of DT offers
             # a way to load collection specific options
-            url = self.datastore.urls.get("datastore", "search")
+            url_static = self.datastore.urls.get("datastore", "search options")
+            url = url_static + "?pi=" + self._id
             auth = self.datastore.token.auth
             response = requests.get(
                 url,
@@ -281,7 +290,7 @@ class Collection:
                     "User-Agent": str(__title__ + "/" + __version__),
                 },
             )
-            response.raise_for_status()
+            eumdac_raise_for_status("Could not get search options", response, CollectionError)
             root = ElementTree.fromstring(response.text)
             (element,) = [
                 ele
@@ -299,3 +308,7 @@ class Collection:
                 and e.get("name") is not None
             }
         return self._search_options
+
+
+class CollectionError(EumdacError):
+    """Errors related to collections"""
