@@ -1,23 +1,25 @@
 from __future__ import annotations
-from .__version__ import __title__, __documentation__, __version__  # noqa
+
+from typing import TYPE_CHECKING
 
 import requests
 
 from eumdac.collection import Collection
+from eumdac.errors import EumdacError, eumdac_raise_for_status
 from eumdac.product import Product
 from eumdac.subscription import Subscription
 from eumdac.token import AccessToken, URLs
 
-from typing import TYPE_CHECKING
+from .__version__ import __documentation__, __title__, __version__  # noqa
 
 if TYPE_CHECKING:  # pragma: no cover
     import sys
     from typing import Optional
 
     if sys.version_info < (3, 9):
-        from typing import Mapping, Iterable
+        from typing import Iterable, Mapping
     else:
-        from collections.abc import Mapping, Iterable
+        from collections.abc import Iterable, Mapping
 
 
 class DataStore:
@@ -43,7 +45,7 @@ class DataStore:
                 "User-Agent": str(__title__ + "/" + __version__),
             },
         )
-        response.raise_for_status()
+        eumdac_raise_for_status("Load collections failed", response, DataStoreError)
         collection_ids = [item["title"] for item in response.json()["links"]]
         self._collections = {
             collection_id: Collection(collection_id, self) for collection_id in collection_ids
@@ -65,7 +67,7 @@ class DataStore:
                 "User-Agent": str(__title__ + "/" + __version__),
             },
         )
-        response.raise_for_status()
+        eumdac_raise_for_status("Get subscriptions failed", response, DataStoreError)
         return [Subscription(properties["uuid"], self) for properties in response.json()]
 
     def get_collection(self, collection_id: str) -> Collection:
@@ -74,7 +76,7 @@ class DataStore:
         try:
             return self._collections[collection_id]
         except KeyError as error:
-            raise KeyError(f"unknown collection {collection_id}") from error
+            raise DataStoreError(f"unknown collection {collection_id}") from error
 
     def get_product(self, collection_id: str, product_id: str) -> Product:
         """product factory"""
@@ -93,6 +95,10 @@ class DataStore:
             parameters["aoi"] = area_of_interest
         subscriptions_url = self.urls.get("datastore", "subscriptions")
         response = requests.post(subscriptions_url, json=parameters, auth=self.token.auth)
-        response.raise_for_status()
+        eumdac_raise_for_status("Creation of new subscription failed", response, DataStoreError)
         subscription_id = response.json()
         return Subscription(subscription_id, self)
+
+
+class DataStoreError(EumdacError):
+    "Errors related to the DataStore"
