@@ -1,26 +1,28 @@
 """Module contianing the data tailor class"""
 from __future__ import annotations
-from .__version__ import __title__, __documentation__, __version__  # noqa
 
 import json
+from typing import TYPE_CHECKING
 
 import requests
 
 from eumdac.customisation import Customisation
-from eumdac.tailor_models import Filter, RegionOfInterest, Quicklook, Chain, DataTailorCRUD
+from eumdac.errors import EumdacError, eumdac_raise_for_status
+from eumdac.tailor_models import Chain, DataTailorCRUD, Filter, Quicklook, RegionOfInterest
 
-from typing import TYPE_CHECKING
+from .__version__ import __documentation__, __title__, __version__  # noqa
 
 if TYPE_CHECKING:  # pragma: no cover
     import sys
-    from typing import Optional, Any
-    from eumdac.token import AccessToken, URLs
+    from typing import Any, Optional
+
     from eumdac.product import Product
+    from eumdac.token import AccessToken, URLs
 
     if sys.version_info < (3, 9):
-        from typing import Mapping, Sequence, Iterable
+        from typing import Iterable, Mapping, Sequence
     else:
-        from collections.abc import Mapping, Sequence, Iterable
+        from collections.abc import Iterable, Mapping, Sequence
 
 
 class DataTailor:
@@ -52,7 +54,7 @@ class DataTailor:
                 "User-Agent": str(__title__ + "/" + __version__),
             },
         )
-        response.raise_for_status()
+        eumdac_raise_for_status("Could not get customisations", response, DataTailorError)
         customisations = response.json()["data"]
         return [Customisation.from_properties(properties, self) for properties in customisations]
 
@@ -69,7 +71,7 @@ class DataTailor:
                     "User-Agent": str(__title__ + "/" + __version__),
                 },
             )
-            response.raise_for_status()
+            eumdac_raise_for_status("Could not get info", response, DataTailorError)
             self._info = response.json()
         return self._info
 
@@ -86,7 +88,7 @@ class DataTailor:
                     "User-Agent": str(__title__ + "/" + __version__),
                 },
             )
-            response.raise_for_status()
+            eumdac_raise_for_status("Could not get user_info", response, DataTailorError)
             self._user_info = response.json()
         return self._user_info
 
@@ -102,7 +104,7 @@ class DataTailor:
                 "User-Agent": str(__title__ + "/" + __version__),
             },
         )
-        response.raise_for_status()
+        eumdac_raise_for_status("Could not get quota", response, DataTailorError)
         return response.json()
 
     def get_customisation(self, cutomisation_id: str) -> Customisation:
@@ -119,7 +121,10 @@ class DataTailor:
             self.urls.get(
                 "datastore",
                 "download product",
-                vars={"product_id": product._id, "collection_id": product.collection._id},
+                vars={
+                    "product_id": product._id,
+                    "collection_id": product.collection._id,
+                },
             )
             for product in products
         )
@@ -129,8 +134,15 @@ class DataTailor:
         else:
             params["chain_config"] = json.dumps(chain.asdict())
         response = requests.post(
-            self.urls.get("tailor", "customisations"), auth=self.token.auth, params=params
+            self.urls.get("tailor", "customisations"),
+            auth=self.token.auth,
+            params=params,
         )
-        response.raise_for_status()
+        eumdac_raise_for_status("Could not add customizations", response, DataTailorError)
+
         customisation_ids = response.json()["data"]
         return [self.get_customisation(customisation_id) for customisation_id in customisation_ids]
+
+
+class DataTailorError(EumdacError):
+    """Errors related to DataTailor operations"""
