@@ -1,28 +1,30 @@
 """Module containing the Data Store Product class."""
 from __future__ import annotations
-from .__version__ import __title__, __documentation__, __version__  # noqa
 
 import re
-from datetime import datetime
 from contextlib import contextmanager
+from datetime import datetime
 from functools import total_ordering
+from typing import TYPE_CHECKING
 
 import requests
 
-from typing import TYPE_CHECKING
+from .__version__ import __documentation__, __title__, __version__  # noqa
 
 if TYPE_CHECKING:  # pragma: no cover
     import sys
-    from typing import Optional, Any, IO
+    from typing import IO, Any, Optional
 
     if sys.version_info < (3, 9):
-        from typing import Mapping, MutableMapping, Generator, Pattern, Sequence
+        from typing import Generator, Mapping, MutableMapping, Pattern, Sequence
     else:
         from collections.abc import Mapping, MutableMapping, Generator, Sequence
         from re import Pattern
     from eumdac.datastore import DataStore
     from eumdac.collection import Collection
 
+from eumdac.errors import EumdacError, eumdac_raise_for_status
+
 
 @total_ordering
 class Product:
@@ -51,13 +53,13 @@ class Product:
         r"(?P<end>\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}(?:\.\d{3,6})?)?"
     )
 
-    def __init__(self, collection_id: str, prdouct_id: str, datastore: DataStore) -> None:
-        self._id = prdouct_id
+    def __init__(self, collection_id: str, product_id: str, datastore: DataStore) -> None:
+        self._id = product_id
         self.datastore = datastore
         self.collection = self.datastore.get_collection(collection_id)
 
     def __str__(self) -> str:
-        return self._id
+        return str(self._id)
 
     def __repr__(self) -> str:
         return f"{self.__class__}({self.collection._id}, {self._id})"
@@ -71,6 +73,9 @@ class Product:
     def __lt__(self, other: Product) -> bool:
         return (self.collection._id, self._id) < (other.collection._id, other._id)
 
+    def __hash__(self) -> int:
+        return hash(repr(self))
+
     def _ensure_properties(self) -> None:
         if self._properties is not None:
             return
@@ -89,7 +94,9 @@ class Product:
                 "User-Agent": str(__title__ + "/" + __version__),
             },
         )
-        response.raise_for_status()
+        eumdac_raise_for_status(
+            f"Product {self._id} not found in {self.collection._id}", response, ProductError
+        )
         geometry = response.json()["geometry"]
         properties = response.json()["properties"]
         properties.pop("parentIdentifier")
@@ -114,7 +121,9 @@ class Product:
                 "User-Agent": str(__title__ + "/" + __version__),
             },
         )
-        response.raise_for_status()
+        eumdac_raise_for_status(
+            f"Product {self._id} not found in {self.collection._id}", response, ProductError
+        )
         properties = response.json()["properties"]
         links = properties.pop("links")
         self._entries = [link["title"] for link in links["sip-entries"]]
@@ -193,6 +202,18 @@ class Product:
             self._load_sip_entries()
         return tuple(self._entries)  # type: ignore[arg-type]
 
+    @property
+    def url(self) -> str:
+        """URL of the product"""
+        auth = str(self.datastore.token.access_token)
+        url = self.datastore.urls.get(
+            "datastore",
+            "download product",
+            vars={"collection_id": self.collection._id, "product_id": self._id},
+        )
+        download_url = str(url) + "?access_token=" + auth
+        return download_url
+
     @contextmanager
     def open(self, entry: Optional[str] = None) -> Generator[IO[bytes], None, None]:
         """Opens a stream to download the product content.
@@ -223,9 +244,17 @@ class Product:
                 "User-Agent": str(__title__ + "/" + __version__),
             },
         ) as response:
-            response.raise_for_status()
+            eumdac_raise_for_status(
+                f"Could not download Product {self._id} of Collection {self.collection._id}",
+                response,
+                ProductError,
+            )
             match = self._extract_filename.search(response.headers["Content-Disposition"])
             filename = match.group(1)  # type: ignore[union-attr]
             response.raw.name = filename
             response.raw.decode_content = True
             yield response.raw
+
+
+class ProductError(EumdacError):
+    """Errors related to products"""
